@@ -13,8 +13,8 @@ AUC <- function(x, y, group, switchAUC = TRUE){
     }
     x <- sort(x)
     y <- sort(y)
-    nx <- length(x)
-    ny <- length(y)
+    nx <- as.numeric(length(x))
+    ny <- as.numeric(length(y))
     AUC <- (nx*ny + nx*(nx+1)/2 - sum(rank(c(x,y))[1:nx]))/(nx*ny)
     if(AUC < 0.5 & switchAUC){
 	dig <- getOption("digits")
