@@ -10,6 +10,9 @@ IQR(x)
 sIQR(x)
 sd(x)
 
+## ------------------------------------------------------------------------
+meanAD(x)
+
 ## ------------------------------------------------------------------------
 fiveNS(x)
 
@@ -305,6 +308,12 @@ mi.t.test(res$imputations, x = "variable", mu = -1, subset = D$group == "yes",
 t.test(D$variable, D$pair, paired = TRUE)
 mi.t.test(res$imputations, x = "variable", y = "pair", paired = TRUE)
 
+## ------------------------------------------------------------------------
+SD1 <- c(0.149, 0.022, 0.036, 0.085, 0.125, NA, 0.139, 0.124, 0.038)
+SD2 <- c(NA, 0.039, 0.038, 0.087, 0.125, NA, 0.135, 0.126, 0.038)
+SDchange <- c(NA, NA, NA, 0.026, 0.058, NA, NA, NA, NA)
+imputeSD(SD1, SD2, SDchange)
+
 ## ------------------------------------------------------------------------
 x <- c(runif(50, max = 0.6), runif(50, min = 0.4))
 g <- c(rep(0, 50), rep(1, 50))
